---
name: Bug/Error
about: Describe a technical issue
title: ''
labels: bug
assignees: ''

---

**Describe the bug**
A clear and concise description of what the bug is.

**To Reproduce**
Steps to reproduce the behavior:
1. ...

**Expected behavior**
A clear and concise description of what you expected to happen.

**Environment:**
 - OS: [e.g. iOS]
 - Python version:
 - GCC/Clang version:

**Additional context**
Add any other context about the problem here.
